@@ -1,30 +1,33 @@
 package DBIx::dbMan::Extension::Authors;
 
 use strict;
-use vars qw/$VERSION @ISA %authorname/;
-use DBIx::dbMan::Extension;
+use base 'DBIx::dbMan::Extension';
 
-$VERSION = '0.06';
-@ISA = qw/DBIx::dbMan::Extension/;
+our $VERSION = '0.07';
 
 # registered authornames
-%authorname = (
-	'000001' => 'Mgr. Ing. Milan Sorm <sorm@pef.mendelu.cz>',
+our %authorname = (
+	'000001' => 'RNDr. Ing. Milan Sorm <sorm@uikt.mendelu.cz>',
 	'000002' => 'Ing. Frantisek Darena <darena@pef.mendelu.cz>',
-	'000003' => 'Ales Kutin <kutin@pef.mendelu.cz>',
-	'000004' => 'Ondrej \'Kepi\' Kudlik <kudlik@pef.mendelu.cz>',
+	'000003' => 'Ing. Ales Kutin <kutin@uikt.mendelu.cz>',
+	'000004' => 'Ondrej \'Kepi\' Kudlik <kudlik@uikt.mendelu.cz>',
+	'000005' => 'Ing. Tomas Klein <klein@uikt.mendelu.cz>',
 );
 
 1;
 
-sub IDENTIFICATION { return "000001-000012-000006"; }
+sub IDENTIFICATION { return "000001-000012-000007"; }
 
-sub author { return 'Mgr. Ing. Milan Sorm <sorm@pef.mendelu.cz>'; }
+sub author { return 'RNDr. Ing. Milan Sorm <sorm@uikt.mendelu.cz>'; }
 
 sub preference { return 0; }
 
 sub known_actions { return [ qw/AUTHORS/ ]; }
 
+sub menu {
+	return ( '_Help' => [ { name => 'Authors', command => 'AUTHORS' } ] );
+}
+
 sub handle_action {
 	my ($obj,%action) = @_;
 
