@@ -1,21 +1,23 @@
 package DBIx::dbMan::Extension::HelpCommands;
 
 use strict;
-use vars qw/$VERSION @ISA/;
-use DBIx::dbMan::Extension;
+use base 'DBIx::dbMan::Extension';
 use Text::FormatTable;
 
-$VERSION = '0.04';
-@ISA = qw/DBIx::dbMan::Extension/;
+our $VERSION = '0.05';
 
 1;
 
-sub IDENTIFICATION { return "000001-000010-000004"; }
+sub IDENTIFICATION { return "000001-000010-000005"; }
 
 sub preference { return 0; }
 
 sub known_actions { return [ qw/HELP/ ]; }
 
+sub menu {
+	return ( '_Help' => [ { name => 'Help', command => 'HELP' } ] );
+}
+
 sub handle_action {
 	my ($obj,%action) = @_;
 
